diff a/test/hotspot/jtreg/runtime/valhalla/inlinetypes/classfileparser/IllegalFieldModifiers.java b/test/hotspot/jtreg/runtime/valhalla/inlinetypes/classfileparser/IllegalFieldModifiers.java
--- /dev/null
+++ b/test/hotspot/jtreg/runtime/valhalla/inlinetypes/classfileparser/IllegalFieldModifiers.java
@@ -0,0 +1,63 @@
+
+
+/*
+ * Copyright (c) 2024, 2024, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ *
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.
+ *
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
+ *
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
+ *
+ */
+/*
+ * @test
+ * @summary test that illegal field modifiers are detected correctly
+ * @enablePreview
+ * @compile fieldModifiersTest.jcod
+ * @run main/othervm -Xverify:remote IllegalFieldModifiers
+ */
+
+
+public class IllegalFieldModifiers {
+
+  public static void runTest(String test_name, String message) throws Exception {
+      System.out.println("Testing: " + test_name);
+      try {
+          Class newClass = Class.forName(test_name);
+      } catch (java.lang.ClassFormatError e) {
+          if (!e.getMessage().contains(message)) {
+              throw new RuntimeException( "Wrong ClassFormatError: " + e.getMessage());
+          }
+      }
+  }
+
+  public static void main(String[] args) throws Exception {
+
+    // Test that ACC_FINAL with ACC_VOLATILE is illegal.
+    runTest("FinalAndVolatile", "Illegal field modifiers in class FinalAndVolatile");
+
+    // Test that ACC_STATIC with ACC_STRICT is illegal.
+    runTest("StrictAndStatic", "Illegal field modifiers in class StrictAndStatic");
+
+    // Test that ACC_STRICT without ACC_FINAL is illegal.
+    runTest("StrictNotFinal", "Illegal field modifiers in class StrictNotFinal");
+
+    // Test that a value class cannot have field without ACC_STATIC or ACC_STRICT
+    runTest("NotStaticNotStrict", "Illegal field modifiers in class NotStaticNotStrict");
+  }
+
+}
